@@ -22,7 +22,8 @@ def test_get_doc(editor):
     editor.setPlainText('open')
     TextHelper(editor).goto_line(1, 1)
     panel._on_action_quick_doc_triggered()
-    QTest.qWait(2000)
+    editor.show()
+    QTest.qWait(1000)
     assert panel.isVisible()
     assert 'open' in panel.text_edit.toPlainText()
     editor.clear()
